Create formatted parameters that specify an s3 bucket board
Source:R/board_params_set_s3.R
board_params_set_s3.RdBuild a data frame that contains all of the parameters needed to specify an s3 bucket pin board. The function validates the provided parameters and returns a standardized data frame for use with other daapr functions.
Arguments
- bucket_name
The name of the s3 bucket where the data product will be stored. Must be a non-empty string.
- prefix
The prefix within this bucket where the data product will be stored. Typically ends with
/for S3 directory handling. Optional, defaults to NULL.- region
The AWS region where the s3 bucket was created, e.g. "us-east-1" or "us-west-1". Must be a non-empty string. The function will check if the provided region is in the list of known AWS availability zones and issue a warning if it's not.
- board_alias
A short name for the board.
This argument is deprecated with pins ≥ 1.0 and will be removed in a future version. Using this parameter will result in an error.